# Generated by Django 4.2.20 on 2026-01-06 02:47

# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("georgeforge", "0025_alter_estimated_delivery_date_to_string"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="order",
            name="on_behalf_of",
        ),
    ]
