<style>
    .editable:hover {
        background-color: var(--bs-warning-bg-subtle);
        cursor: pointer;
        border-radius: 3px;
        padding: 2px 4px;
        margin: -2px -4px;
    }

    .editable-empty {
        color: var(--bs-secondary-color);
        font-style: italic;
    }

    .table-hover tbody tr:hover .editable {
        background-color: color-mix(in srgb, var(--bs-warning-bg-subtle) 70%, transparent);
    }
</style>
