# Generated by Django 4.2.27 on 2026-01-24 20:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('georgeforge', '0028_alter_order_estimated_delivery_date'),
    ]

    operations = [
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.IntegerField(choices=[(10, 'Pending'), (20, 'Awaiting Deposit'), (25, 'Deposit Recieved'), (30, 'Building Parts'), (35, 'Building Hull'), (40, 'Contract Up'), (50, 'Delivered'), (60, 'Rejected')], verbose_name='Status'),
        ),
    ]
