{% extends "georgeforge/base.html" %}
{% load i18n %}
{% load humanize %}
{% load static %}
{% load django_bootstrap5 %}
{% block details %}
    <form method="get" action="{% url 'georgeforge:export_offers' %}">
        <input class="btn btn-primary" type="submit" value="Download CSV" />
    </form>
    <form class="m-3"
          method="post"
          id="order-form"
          action="{% url 'georgeforge:bulk_import_form' %}">
        {% csrf_token %} {% bootstrap_form form %}
        <input class="btn btn-primary" type="submit" />
    </form>
{% endblock details %}
{% block extra_javascript %}
{% endblock extra_javascript %}
{% block extra_css %}
{% endblock extra_css %}
{% block extra_script %}
{% endblock extra_script %}
