# Generated by Django 4.2.27 on 2026-01-24 19:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('georgeforge', '0027_alter_order_estimated_delivery_date'),
    ]

    operations = [
        migrations.AlterField(
            model_name='order',
            name='estimated_delivery_date',
            field=models.CharField(blank=True, help_text='Estimated date when the order will be delivered', max_length=50, verbose_name='Estimated Delivery Date'),
        ),
    ]
